# coding: utf-8

"""
    Marketing Emails

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.emails.configuration import Configuration


class PublicEmailStyleSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "email_body_padding": "str",
        "color_picker_favorite5": "str",
        "body_color": "str",
        "color_picker_favorite6": "str",
        "background_image": "str",
        "email_body_width": "str",
        "secondary_font": "str",
        "primary_accent_color": "str",
        "color_picker_favorite3": "str",
        "primary_font_line_height": "str",
        "color_picker_favorite4": "str",
        "secondary_font_color": "str",
        "color_picker_favorite1": "str",
        "color_picker_favorite2": "str",
        "body_border_color": "str",
        "body_border_width": "int",
        "links_font": "PublicFontStyle",
        "background_color": "str",
        "background_image_type": "str",
        "divider_style_settings": "PublicDividerStyleSettings",
        "secondary_accent_color": "str",
        "secondary_font_line_height": "str",
        "primary_font_size": "int",
        "secondary_font_size": "int",
        "primary_font_color": "str",
        "heading_one_font": "PublicFontStyle",
        "primary_font": "str",
        "heading_two_font": "PublicFontStyle",
        "button_style_settings": "PublicButtonStyleSettings",
        "body_border_color_choice": "str",
    }

    attribute_map = {
        "email_body_padding": "emailBodyPadding",
        "color_picker_favorite5": "colorPickerFavorite5",
        "body_color": "bodyColor",
        "color_picker_favorite6": "colorPickerFavorite6",
        "background_image": "backgroundImage",
        "email_body_width": "emailBodyWidth",
        "secondary_font": "secondaryFont",
        "primary_accent_color": "primaryAccentColor",
        "color_picker_favorite3": "colorPickerFavorite3",
        "primary_font_line_height": "primaryFontLineHeight",
        "color_picker_favorite4": "colorPickerFavorite4",
        "secondary_font_color": "secondaryFontColor",
        "color_picker_favorite1": "colorPickerFavorite1",
        "color_picker_favorite2": "colorPickerFavorite2",
        "body_border_color": "bodyBorderColor",
        "body_border_width": "bodyBorderWidth",
        "links_font": "linksFont",
        "background_color": "backgroundColor",
        "background_image_type": "backgroundImageType",
        "divider_style_settings": "dividerStyleSettings",
        "secondary_accent_color": "secondaryAccentColor",
        "secondary_font_line_height": "secondaryFontLineHeight",
        "primary_font_size": "primaryFontSize",
        "secondary_font_size": "secondaryFontSize",
        "primary_font_color": "primaryFontColor",
        "heading_one_font": "headingOneFont",
        "primary_font": "primaryFont",
        "heading_two_font": "headingTwoFont",
        "button_style_settings": "buttonStyleSettings",
        "body_border_color_choice": "bodyBorderColorChoice",
    }

    def __init__(
        self,
        email_body_padding=None,
        color_picker_favorite5=None,
        body_color=None,
        color_picker_favorite6=None,
        background_image=None,
        email_body_width=None,
        secondary_font=None,
        primary_accent_color=None,
        color_picker_favorite3=None,
        primary_font_line_height=None,
        color_picker_favorite4=None,
        secondary_font_color=None,
        color_picker_favorite1=None,
        color_picker_favorite2=None,
        body_border_color=None,
        body_border_width=None,
        links_font=None,
        background_color=None,
        background_image_type=None,
        divider_style_settings=None,
        secondary_accent_color=None,
        secondary_font_line_height=None,
        primary_font_size=None,
        secondary_font_size=None,
        primary_font_color=None,
        heading_one_font=None,
        primary_font=None,
        heading_two_font=None,
        button_style_settings=None,
        body_border_color_choice=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicEmailStyleSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._email_body_padding = None
        self._color_picker_favorite5 = None
        self._body_color = None
        self._color_picker_favorite6 = None
        self._background_image = None
        self._email_body_width = None
        self._secondary_font = None
        self._primary_accent_color = None
        self._color_picker_favorite3 = None
        self._primary_font_line_height = None
        self._color_picker_favorite4 = None
        self._secondary_font_color = None
        self._color_picker_favorite1 = None
        self._color_picker_favorite2 = None
        self._body_border_color = None
        self._body_border_width = None
        self._links_font = None
        self._background_color = None
        self._background_image_type = None
        self._divider_style_settings = None
        self._secondary_accent_color = None
        self._secondary_font_line_height = None
        self._primary_font_size = None
        self._secondary_font_size = None
        self._primary_font_color = None
        self._heading_one_font = None
        self._primary_font = None
        self._heading_two_font = None
        self._button_style_settings = None
        self._body_border_color_choice = None
        self.discriminator = None

        if email_body_padding is not None:
            self.email_body_padding = email_body_padding
        if color_picker_favorite5 is not None:
            self.color_picker_favorite5 = color_picker_favorite5
        if body_color is not None:
            self.body_color = body_color
        if color_picker_favorite6 is not None:
            self.color_picker_favorite6 = color_picker_favorite6
        if background_image is not None:
            self.background_image = background_image
        if email_body_width is not None:
            self.email_body_width = email_body_width
        if secondary_font is not None:
            self.secondary_font = secondary_font
        if primary_accent_color is not None:
            self.primary_accent_color = primary_accent_color
        if color_picker_favorite3 is not None:
            self.color_picker_favorite3 = color_picker_favorite3
        if primary_font_line_height is not None:
            self.primary_font_line_height = primary_font_line_height
        if color_picker_favorite4 is not None:
            self.color_picker_favorite4 = color_picker_favorite4
        if secondary_font_color is not None:
            self.secondary_font_color = secondary_font_color
        if color_picker_favorite1 is not None:
            self.color_picker_favorite1 = color_picker_favorite1
        if color_picker_favorite2 is not None:
            self.color_picker_favorite2 = color_picker_favorite2
        if body_border_color is not None:
            self.body_border_color = body_border_color
        if body_border_width is not None:
            self.body_border_width = body_border_width
        if links_font is not None:
            self.links_font = links_font
        if background_color is not None:
            self.background_color = background_color
        if background_image_type is not None:
            self.background_image_type = background_image_type
        if divider_style_settings is not None:
            self.divider_style_settings = divider_style_settings
        if secondary_accent_color is not None:
            self.secondary_accent_color = secondary_accent_color
        if secondary_font_line_height is not None:
            self.secondary_font_line_height = secondary_font_line_height
        if primary_font_size is not None:
            self.primary_font_size = primary_font_size
        if secondary_font_size is not None:
            self.secondary_font_size = secondary_font_size
        if primary_font_color is not None:
            self.primary_font_color = primary_font_color
        if heading_one_font is not None:
            self.heading_one_font = heading_one_font
        if primary_font is not None:
            self.primary_font = primary_font
        if heading_two_font is not None:
            self.heading_two_font = heading_two_font
        if button_style_settings is not None:
            self.button_style_settings = button_style_settings
        if body_border_color_choice is not None:
            self.body_border_color_choice = body_border_color_choice

    @property
    def email_body_padding(self):
        """Gets the email_body_padding of this PublicEmailStyleSettings.  # noqa: E501


        :return: The email_body_padding of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._email_body_padding

    @email_body_padding.setter
    def email_body_padding(self, email_body_padding):
        """Sets the email_body_padding of this PublicEmailStyleSettings.


        :param email_body_padding: The email_body_padding of this PublicEmailStyleSettings.  # noqa: E501
        :type email_body_padding: str
        """

        self._email_body_padding = email_body_padding

    @property
    def color_picker_favorite5(self):
        """Gets the color_picker_favorite5 of this PublicEmailStyleSettings.  # noqa: E501


        :return: The color_picker_favorite5 of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._color_picker_favorite5

    @color_picker_favorite5.setter
    def color_picker_favorite5(self, color_picker_favorite5):
        """Sets the color_picker_favorite5 of this PublicEmailStyleSettings.


        :param color_picker_favorite5: The color_picker_favorite5 of this PublicEmailStyleSettings.  # noqa: E501
        :type color_picker_favorite5: str
        """

        self._color_picker_favorite5 = color_picker_favorite5

    @property
    def body_color(self):
        """Gets the body_color of this PublicEmailStyleSettings.  # noqa: E501


        :return: The body_color of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._body_color

    @body_color.setter
    def body_color(self, body_color):
        """Sets the body_color of this PublicEmailStyleSettings.


        :param body_color: The body_color of this PublicEmailStyleSettings.  # noqa: E501
        :type body_color: str
        """

        self._body_color = body_color

    @property
    def color_picker_favorite6(self):
        """Gets the color_picker_favorite6 of this PublicEmailStyleSettings.  # noqa: E501


        :return: The color_picker_favorite6 of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._color_picker_favorite6

    @color_picker_favorite6.setter
    def color_picker_favorite6(self, color_picker_favorite6):
        """Sets the color_picker_favorite6 of this PublicEmailStyleSettings.


        :param color_picker_favorite6: The color_picker_favorite6 of this PublicEmailStyleSettings.  # noqa: E501
        :type color_picker_favorite6: str
        """

        self._color_picker_favorite6 = color_picker_favorite6

    @property
    def background_image(self):
        """Gets the background_image of this PublicEmailStyleSettings.  # noqa: E501


        :return: The background_image of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._background_image

    @background_image.setter
    def background_image(self, background_image):
        """Sets the background_image of this PublicEmailStyleSettings.


        :param background_image: The background_image of this PublicEmailStyleSettings.  # noqa: E501
        :type background_image: str
        """

        self._background_image = background_image

    @property
    def email_body_width(self):
        """Gets the email_body_width of this PublicEmailStyleSettings.  # noqa: E501


        :return: The email_body_width of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._email_body_width

    @email_body_width.setter
    def email_body_width(self, email_body_width):
        """Sets the email_body_width of this PublicEmailStyleSettings.


        :param email_body_width: The email_body_width of this PublicEmailStyleSettings.  # noqa: E501
        :type email_body_width: str
        """

        self._email_body_width = email_body_width

    @property
    def secondary_font(self):
        """Gets the secondary_font of this PublicEmailStyleSettings.  # noqa: E501


        :return: The secondary_font of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._secondary_font

    @secondary_font.setter
    def secondary_font(self, secondary_font):
        """Sets the secondary_font of this PublicEmailStyleSettings.


        :param secondary_font: The secondary_font of this PublicEmailStyleSettings.  # noqa: E501
        :type secondary_font: str
        """

        self._secondary_font = secondary_font

    @property
    def primary_accent_color(self):
        """Gets the primary_accent_color of this PublicEmailStyleSettings.  # noqa: E501


        :return: The primary_accent_color of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._primary_accent_color

    @primary_accent_color.setter
    def primary_accent_color(self, primary_accent_color):
        """Sets the primary_accent_color of this PublicEmailStyleSettings.


        :param primary_accent_color: The primary_accent_color of this PublicEmailStyleSettings.  # noqa: E501
        :type primary_accent_color: str
        """

        self._primary_accent_color = primary_accent_color

    @property
    def color_picker_favorite3(self):
        """Gets the color_picker_favorite3 of this PublicEmailStyleSettings.  # noqa: E501


        :return: The color_picker_favorite3 of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._color_picker_favorite3

    @color_picker_favorite3.setter
    def color_picker_favorite3(self, color_picker_favorite3):
        """Sets the color_picker_favorite3 of this PublicEmailStyleSettings.


        :param color_picker_favorite3: The color_picker_favorite3 of this PublicEmailStyleSettings.  # noqa: E501
        :type color_picker_favorite3: str
        """

        self._color_picker_favorite3 = color_picker_favorite3

    @property
    def primary_font_line_height(self):
        """Gets the primary_font_line_height of this PublicEmailStyleSettings.  # noqa: E501


        :return: The primary_font_line_height of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._primary_font_line_height

    @primary_font_line_height.setter
    def primary_font_line_height(self, primary_font_line_height):
        """Sets the primary_font_line_height of this PublicEmailStyleSettings.


        :param primary_font_line_height: The primary_font_line_height of this PublicEmailStyleSettings.  # noqa: E501
        :type primary_font_line_height: str
        """

        self._primary_font_line_height = primary_font_line_height

    @property
    def color_picker_favorite4(self):
        """Gets the color_picker_favorite4 of this PublicEmailStyleSettings.  # noqa: E501


        :return: The color_picker_favorite4 of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._color_picker_favorite4

    @color_picker_favorite4.setter
    def color_picker_favorite4(self, color_picker_favorite4):
        """Sets the color_picker_favorite4 of this PublicEmailStyleSettings.


        :param color_picker_favorite4: The color_picker_favorite4 of this PublicEmailStyleSettings.  # noqa: E501
        :type color_picker_favorite4: str
        """

        self._color_picker_favorite4 = color_picker_favorite4

    @property
    def secondary_font_color(self):
        """Gets the secondary_font_color of this PublicEmailStyleSettings.  # noqa: E501


        :return: The secondary_font_color of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._secondary_font_color

    @secondary_font_color.setter
    def secondary_font_color(self, secondary_font_color):
        """Sets the secondary_font_color of this PublicEmailStyleSettings.


        :param secondary_font_color: The secondary_font_color of this PublicEmailStyleSettings.  # noqa: E501
        :type secondary_font_color: str
        """

        self._secondary_font_color = secondary_font_color

    @property
    def color_picker_favorite1(self):
        """Gets the color_picker_favorite1 of this PublicEmailStyleSettings.  # noqa: E501


        :return: The color_picker_favorite1 of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._color_picker_favorite1

    @color_picker_favorite1.setter
    def color_picker_favorite1(self, color_picker_favorite1):
        """Sets the color_picker_favorite1 of this PublicEmailStyleSettings.


        :param color_picker_favorite1: The color_picker_favorite1 of this PublicEmailStyleSettings.  # noqa: E501
        :type color_picker_favorite1: str
        """

        self._color_picker_favorite1 = color_picker_favorite1

    @property
    def color_picker_favorite2(self):
        """Gets the color_picker_favorite2 of this PublicEmailStyleSettings.  # noqa: E501


        :return: The color_picker_favorite2 of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._color_picker_favorite2

    @color_picker_favorite2.setter
    def color_picker_favorite2(self, color_picker_favorite2):
        """Sets the color_picker_favorite2 of this PublicEmailStyleSettings.


        :param color_picker_favorite2: The color_picker_favorite2 of this PublicEmailStyleSettings.  # noqa: E501
        :type color_picker_favorite2: str
        """

        self._color_picker_favorite2 = color_picker_favorite2

    @property
    def body_border_color(self):
        """Gets the body_border_color of this PublicEmailStyleSettings.  # noqa: E501


        :return: The body_border_color of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._body_border_color

    @body_border_color.setter
    def body_border_color(self, body_border_color):
        """Sets the body_border_color of this PublicEmailStyleSettings.


        :param body_border_color: The body_border_color of this PublicEmailStyleSettings.  # noqa: E501
        :type body_border_color: str
        """

        self._body_border_color = body_border_color

    @property
    def body_border_width(self):
        """Gets the body_border_width of this PublicEmailStyleSettings.  # noqa: E501


        :return: The body_border_width of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: int
        """
        return self._body_border_width

    @body_border_width.setter
    def body_border_width(self, body_border_width):
        """Sets the body_border_width of this PublicEmailStyleSettings.


        :param body_border_width: The body_border_width of this PublicEmailStyleSettings.  # noqa: E501
        :type body_border_width: int
        """

        self._body_border_width = body_border_width

    @property
    def links_font(self):
        """Gets the links_font of this PublicEmailStyleSettings.  # noqa: E501


        :return: The links_font of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: PublicFontStyle
        """
        return self._links_font

    @links_font.setter
    def links_font(self, links_font):
        """Sets the links_font of this PublicEmailStyleSettings.


        :param links_font: The links_font of this PublicEmailStyleSettings.  # noqa: E501
        :type links_font: PublicFontStyle
        """

        self._links_font = links_font

    @property
    def background_color(self):
        """Gets the background_color of this PublicEmailStyleSettings.  # noqa: E501


        :return: The background_color of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """Sets the background_color of this PublicEmailStyleSettings.


        :param background_color: The background_color of this PublicEmailStyleSettings.  # noqa: E501
        :type background_color: str
        """

        self._background_color = background_color

    @property
    def background_image_type(self):
        """Gets the background_image_type of this PublicEmailStyleSettings.  # noqa: E501


        :return: The background_image_type of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._background_image_type

    @background_image_type.setter
    def background_image_type(self, background_image_type):
        """Sets the background_image_type of this PublicEmailStyleSettings.


        :param background_image_type: The background_image_type of this PublicEmailStyleSettings.  # noqa: E501
        :type background_image_type: str
        """

        self._background_image_type = background_image_type

    @property
    def divider_style_settings(self):
        """Gets the divider_style_settings of this PublicEmailStyleSettings.  # noqa: E501


        :return: The divider_style_settings of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: PublicDividerStyleSettings
        """
        return self._divider_style_settings

    @divider_style_settings.setter
    def divider_style_settings(self, divider_style_settings):
        """Sets the divider_style_settings of this PublicEmailStyleSettings.


        :param divider_style_settings: The divider_style_settings of this PublicEmailStyleSettings.  # noqa: E501
        :type divider_style_settings: PublicDividerStyleSettings
        """

        self._divider_style_settings = divider_style_settings

    @property
    def secondary_accent_color(self):
        """Gets the secondary_accent_color of this PublicEmailStyleSettings.  # noqa: E501


        :return: The secondary_accent_color of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._secondary_accent_color

    @secondary_accent_color.setter
    def secondary_accent_color(self, secondary_accent_color):
        """Sets the secondary_accent_color of this PublicEmailStyleSettings.


        :param secondary_accent_color: The secondary_accent_color of this PublicEmailStyleSettings.  # noqa: E501
        :type secondary_accent_color: str
        """

        self._secondary_accent_color = secondary_accent_color

    @property
    def secondary_font_line_height(self):
        """Gets the secondary_font_line_height of this PublicEmailStyleSettings.  # noqa: E501


        :return: The secondary_font_line_height of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._secondary_font_line_height

    @secondary_font_line_height.setter
    def secondary_font_line_height(self, secondary_font_line_height):
        """Sets the secondary_font_line_height of this PublicEmailStyleSettings.


        :param secondary_font_line_height: The secondary_font_line_height of this PublicEmailStyleSettings.  # noqa: E501
        :type secondary_font_line_height: str
        """

        self._secondary_font_line_height = secondary_font_line_height

    @property
    def primary_font_size(self):
        """Gets the primary_font_size of this PublicEmailStyleSettings.  # noqa: E501


        :return: The primary_font_size of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: int
        """
        return self._primary_font_size

    @primary_font_size.setter
    def primary_font_size(self, primary_font_size):
        """Sets the primary_font_size of this PublicEmailStyleSettings.


        :param primary_font_size: The primary_font_size of this PublicEmailStyleSettings.  # noqa: E501
        :type primary_font_size: int
        """

        self._primary_font_size = primary_font_size

    @property
    def secondary_font_size(self):
        """Gets the secondary_font_size of this PublicEmailStyleSettings.  # noqa: E501


        :return: The secondary_font_size of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: int
        """
        return self._secondary_font_size

    @secondary_font_size.setter
    def secondary_font_size(self, secondary_font_size):
        """Sets the secondary_font_size of this PublicEmailStyleSettings.


        :param secondary_font_size: The secondary_font_size of this PublicEmailStyleSettings.  # noqa: E501
        :type secondary_font_size: int
        """

        self._secondary_font_size = secondary_font_size

    @property
    def primary_font_color(self):
        """Gets the primary_font_color of this PublicEmailStyleSettings.  # noqa: E501


        :return: The primary_font_color of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._primary_font_color

    @primary_font_color.setter
    def primary_font_color(self, primary_font_color):
        """Sets the primary_font_color of this PublicEmailStyleSettings.


        :param primary_font_color: The primary_font_color of this PublicEmailStyleSettings.  # noqa: E501
        :type primary_font_color: str
        """

        self._primary_font_color = primary_font_color

    @property
    def heading_one_font(self):
        """Gets the heading_one_font of this PublicEmailStyleSettings.  # noqa: E501


        :return: The heading_one_font of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: PublicFontStyle
        """
        return self._heading_one_font

    @heading_one_font.setter
    def heading_one_font(self, heading_one_font):
        """Sets the heading_one_font of this PublicEmailStyleSettings.


        :param heading_one_font: The heading_one_font of this PublicEmailStyleSettings.  # noqa: E501
        :type heading_one_font: PublicFontStyle
        """

        self._heading_one_font = heading_one_font

    @property
    def primary_font(self):
        """Gets the primary_font of this PublicEmailStyleSettings.  # noqa: E501


        :return: The primary_font of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._primary_font

    @primary_font.setter
    def primary_font(self, primary_font):
        """Sets the primary_font of this PublicEmailStyleSettings.


        :param primary_font: The primary_font of this PublicEmailStyleSettings.  # noqa: E501
        :type primary_font: str
        """

        self._primary_font = primary_font

    @property
    def heading_two_font(self):
        """Gets the heading_two_font of this PublicEmailStyleSettings.  # noqa: E501


        :return: The heading_two_font of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: PublicFontStyle
        """
        return self._heading_two_font

    @heading_two_font.setter
    def heading_two_font(self, heading_two_font):
        """Sets the heading_two_font of this PublicEmailStyleSettings.


        :param heading_two_font: The heading_two_font of this PublicEmailStyleSettings.  # noqa: E501
        :type heading_two_font: PublicFontStyle
        """

        self._heading_two_font = heading_two_font

    @property
    def button_style_settings(self):
        """Gets the button_style_settings of this PublicEmailStyleSettings.  # noqa: E501


        :return: The button_style_settings of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: PublicButtonStyleSettings
        """
        return self._button_style_settings

    @button_style_settings.setter
    def button_style_settings(self, button_style_settings):
        """Sets the button_style_settings of this PublicEmailStyleSettings.


        :param button_style_settings: The button_style_settings of this PublicEmailStyleSettings.  # noqa: E501
        :type button_style_settings: PublicButtonStyleSettings
        """

        self._button_style_settings = button_style_settings

    @property
    def body_border_color_choice(self):
        """Gets the body_border_color_choice of this PublicEmailStyleSettings.  # noqa: E501


        :return: The body_border_color_choice of this PublicEmailStyleSettings.  # noqa: E501
        :rtype: str
        """
        return self._body_border_color_choice

    @body_border_color_choice.setter
    def body_border_color_choice(self, body_border_color_choice):
        """Sets the body_border_color_choice of this PublicEmailStyleSettings.


        :param body_border_color_choice: The body_border_color_choice of this PublicEmailStyleSettings.  # noqa: E501
        :type body_border_color_choice: str
        """

        self._body_border_color_choice = body_border_color_choice

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicEmailStyleSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicEmailStyleSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Hubdb

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.cms.hubdb.api_client import ApiClient
from hubspot.cms.hubdb.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class RowsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def clone_draft_table_row(self, table_id_or_name, row_id, **kwargs):  # noqa: E501
        """Clone a row  # noqa: E501

        Clones a single row in the draft version of a table.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.clone_draft_table_row(table_id_or_name, row_id, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table (required)
        :type table_id_or_name: str
        :param row_id: The ID of the row (required)
        :type row_id: str
        :param name:
        :type name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HubDbTableRowV3
        """
        kwargs["_return_http_data_only"] = True
        return self.clone_draft_table_row_with_http_info(table_id_or_name, row_id, **kwargs)  # noqa: E501

    def clone_draft_table_row_with_http_info(self, table_id_or_name, row_id, **kwargs):  # noqa: E501
        """Clone a row  # noqa: E501

        Clones a single row in the draft version of a table.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.clone_draft_table_row_with_http_info(table_id_or_name, row_id, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table (required)
        :type table_id_or_name: str
        :param row_id: The ID of the row (required)
        :type row_id: str
        :param name:
        :type name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(HubDbTableRowV3, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["table_id_or_name", "row_id", "name"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method clone_draft_table_row" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'table_id_or_name' is set
        if self.api_client.client_side_validation and local_var_params.get("table_id_or_name") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `table_id_or_name` when calling `clone_draft_table_row`")  # noqa: E501
        # verify the required parameter 'row_id' is set
        if self.api_client.client_side_validation and local_var_params.get("row_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `row_id` when calling `clone_draft_table_row`")  # noqa: E501

        if self.api_client.client_side_validation and "row_id" in local_var_params and not re.search(r"\d+", local_var_params["row_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `row_id` when calling `clone_draft_table_row`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "table_id_or_name" in local_var_params:
            path_params["tableIdOrName"] = local_var_params["table_id_or_name"]  # noqa: E501
        if "row_id" in local_var_params:
            path_params["rowId"] = local_var_params["row_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("name") is not None:  # noqa: E501
            query_params.append(("name", local_var_params["name"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "HubDbTableRowV3",
        }

        return self.api_client.call_api(
            "/cms/v3/hubdb/tables/{tableIdOrName}/rows/{rowId}/draft/clone",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create_table_row(self, table_id_or_name, hub_db_table_row_v3_request, **kwargs):  # noqa: E501
        """Add a new row to a table  # noqa: E501

        Add a new row to a HubDB table. New rows will be added to the draft version of the table. Use the `/publish` endpoint to push these changes to published version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_table_row(table_id_or_name, hub_db_table_row_v3_request, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the target table. (required)
        :type table_id_or_name: str
        :param hub_db_table_row_v3_request: (required)
        :type hub_db_table_row_v3_request: HubDbTableRowV3Request
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HubDbTableRowV3
        """
        kwargs["_return_http_data_only"] = True
        return self.create_table_row_with_http_info(table_id_or_name, hub_db_table_row_v3_request, **kwargs)  # noqa: E501

    def create_table_row_with_http_info(self, table_id_or_name, hub_db_table_row_v3_request, **kwargs):  # noqa: E501
        """Add a new row to a table  # noqa: E501

        Add a new row to a HubDB table. New rows will be added to the draft version of the table. Use the `/publish` endpoint to push these changes to published version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_table_row_with_http_info(table_id_or_name, hub_db_table_row_v3_request, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the target table. (required)
        :type table_id_or_name: str
        :param hub_db_table_row_v3_request: (required)
        :type hub_db_table_row_v3_request: HubDbTableRowV3Request
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(HubDbTableRowV3, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["table_id_or_name", "hub_db_table_row_v3_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create_table_row" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'table_id_or_name' is set
        if self.api_client.client_side_validation and local_var_params.get("table_id_or_name") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `table_id_or_name` when calling `create_table_row`")  # noqa: E501
        # verify the required parameter 'hub_db_table_row_v3_request' is set
        if self.api_client.client_side_validation and local_var_params.get("hub_db_table_row_v3_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `hub_db_table_row_v3_request` when calling `create_table_row`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "table_id_or_name" in local_var_params:
            path_params["tableIdOrName"] = local_var_params["table_id_or_name"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "hub_db_table_row_v3_request" in local_var_params:
            body_params = local_var_params["hub_db_table_row_v3_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            201: "HubDbTableRowV3",
        }

        return self.api_client.call_api(
            "/cms/v3/hubdb/tables/{tableIdOrName}/rows",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_draft_table_row_by_id(self, table_id_or_name, row_id, **kwargs):  # noqa: E501
        """Get a row from the draft table  # noqa: E501

        Get a single row by ID from a table's draft version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_draft_table_row_by_id(table_id_or_name, row_id, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table (required)
        :type table_id_or_name: str
        :param row_id: The ID of the row (required)
        :type row_id: str
        :param archived:
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HubDbTableRowV3
        """
        kwargs["_return_http_data_only"] = True
        return self.get_draft_table_row_by_id_with_http_info(table_id_or_name, row_id, **kwargs)  # noqa: E501

    def get_draft_table_row_by_id_with_http_info(self, table_id_or_name, row_id, **kwargs):  # noqa: E501
        """Get a row from the draft table  # noqa: E501

        Get a single row by ID from a table's draft version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_draft_table_row_by_id_with_http_info(table_id_or_name, row_id, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table (required)
        :type table_id_or_name: str
        :param row_id: The ID of the row (required)
        :type row_id: str
        :param archived:
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(HubDbTableRowV3, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["table_id_or_name", "row_id", "archived"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_draft_table_row_by_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'table_id_or_name' is set
        if self.api_client.client_side_validation and local_var_params.get("table_id_or_name") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `table_id_or_name` when calling `get_draft_table_row_by_id`")  # noqa: E501
        # verify the required parameter 'row_id' is set
        if self.api_client.client_side_validation and local_var_params.get("row_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `row_id` when calling `get_draft_table_row_by_id`")  # noqa: E501

        if self.api_client.client_side_validation and "row_id" in local_var_params and not re.search(r"\d+", local_var_params["row_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `row_id` when calling `get_draft_table_row_by_id`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "table_id_or_name" in local_var_params:
            path_params["tableIdOrName"] = local_var_params["table_id_or_name"]  # noqa: E501
        if "row_id" in local_var_params:
            path_params["rowId"] = local_var_params["row_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("archived") is not None:  # noqa: E501
            query_params.append(("archived", local_var_params["archived"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "HubDbTableRowV3",
        }

        return self.api_client.call_api(
            "/cms/v3/hubdb/tables/{tableIdOrName}/rows/{rowId}/draft",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_table_row(self, table_id_or_name, row_id, **kwargs):  # noqa: E501
        """Get a table row  # noqa: E501

        Get a single row by ID from the published version of a table. **Note:** This endpoint can be accessed without any authentication, if the table is set to be allowed for public access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_table_row(table_id_or_name, row_id, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table (required)
        :type table_id_or_name: str
        :param row_id: The ID of the row (required)
        :type row_id: str
        :param archived:
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HubDbTableRowV3
        """
        kwargs["_return_http_data_only"] = True
        return self.get_table_row_with_http_info(table_id_or_name, row_id, **kwargs)  # noqa: E501

    def get_table_row_with_http_info(self, table_id_or_name, row_id, **kwargs):  # noqa: E501
        """Get a table row  # noqa: E501

        Get a single row by ID from the published version of a table. **Note:** This endpoint can be accessed without any authentication, if the table is set to be allowed for public access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_table_row_with_http_info(table_id_or_name, row_id, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table (required)
        :type table_id_or_name: str
        :param row_id: The ID of the row (required)
        :type row_id: str
        :param archived:
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(HubDbTableRowV3, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["table_id_or_name", "row_id", "archived"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_table_row" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'table_id_or_name' is set
        if self.api_client.client_side_validation and local_var_params.get("table_id_or_name") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `table_id_or_name` when calling `get_table_row`")  # noqa: E501
        # verify the required parameter 'row_id' is set
        if self.api_client.client_side_validation and local_var_params.get("row_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `row_id` when calling `get_table_row`")  # noqa: E501

        if self.api_client.client_side_validation and "row_id" in local_var_params and not re.search(r"\d+", local_var_params["row_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `row_id` when calling `get_table_row`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "table_id_or_name" in local_var_params:
            path_params["tableIdOrName"] = local_var_params["table_id_or_name"]  # noqa: E501
        if "row_id" in local_var_params:
            path_params["rowId"] = local_var_params["row_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("archived") is not None:  # noqa: E501
            query_params.append(("archived", local_var_params["archived"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "HubDbTableRowV3",
        }

        return self.api_client.call_api(
            "/cms/v3/hubdb/tables/{tableIdOrName}/rows/{rowId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_table_rows(self, table_id_or_name, **kwargs):  # noqa: E501
        """Get rows for a table  # noqa: E501

        Returns a set of rows in the published version of the specified table. Row results can be filtered and sorted. Filtering and sorting options will be sent as query parameters to the API request. For example, by adding the query parameters `column1__gt=5&sort=-column1`, API returns the rows with values for column `column1` greater than 5 and in the descending order of `column1` values. Refer to the [overview section](https://developers.hubspot.com/docs/api/cms/hubdb#filtering-and-sorting-table-rows) for detailed filtering and sorting options. **Note:** This endpoint can be accessed without any authentication, if the table is set to be allowed for public access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_table_rows(table_id_or_name, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table to query. (required)
        :type table_id_or_name: str
        :param sort: Specifies the column names to sort the results by. See the above description for more details.
        :type sort: list[str]
        :param after: The cursor token value to get the next set of results. You can get this from the `paging.next.after` JSON property of a paged response containing more results.
        :type after: str
        :param limit: The maximum number of results to return. Default is `1000`.
        :type limit: int
        :param properties: Specify the column names to get results containing only the required columns instead of all column details.
        :type properties: list[str]
        :param offset:
        :type offset: int
        :param archived:
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UnifiedCollectionResponseWithTotalBaseHubDbTableRowV3
        """
        kwargs["_return_http_data_only"] = True
        return self.get_table_rows_with_http_info(table_id_or_name, **kwargs)  # noqa: E501

    def get_table_rows_with_http_info(self, table_id_or_name, **kwargs):  # noqa: E501
        """Get rows for a table  # noqa: E501

        Returns a set of rows in the published version of the specified table. Row results can be filtered and sorted. Filtering and sorting options will be sent as query parameters to the API request. For example, by adding the query parameters `column1__gt=5&sort=-column1`, API returns the rows with values for column `column1` greater than 5 and in the descending order of `column1` values. Refer to the [overview section](https://developers.hubspot.com/docs/api/cms/hubdb#filtering-and-sorting-table-rows) for detailed filtering and sorting options. **Note:** This endpoint can be accessed without any authentication, if the table is set to be allowed for public access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_table_rows_with_http_info(table_id_or_name, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table to query. (required)
        :type table_id_or_name: str
        :param sort: Specifies the column names to sort the results by. See the above description for more details.
        :type sort: list[str]
        :param after: The cursor token value to get the next set of results. You can get this from the `paging.next.after` JSON property of a paged response containing more results.
        :type after: str
        :param limit: The maximum number of results to return. Default is `1000`.
        :type limit: int
        :param properties: Specify the column names to get results containing only the required columns instead of all column details.
        :type properties: list[str]
        :param offset:
        :type offset: int
        :param archived:
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(UnifiedCollectionResponseWithTotalBaseHubDbTableRowV3, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["table_id_or_name", "sort", "after", "limit", "properties", "offset", "archived"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_table_rows" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'table_id_or_name' is set
        if self.api_client.client_side_validation and local_var_params.get("table_id_or_name") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `table_id_or_name` when calling `get_table_rows`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "table_id_or_name" in local_var_params:
            path_params["tableIdOrName"] = local_var_params["table_id_or_name"]  # noqa: E501

        query_params = []
        if local_var_params.get("sort") is not None:  # noqa: E501
            query_params.append(("sort", local_var_params["sort"]))  # noqa: E501
            collection_formats["sort"] = "multi"  # noqa: E501
        if local_var_params.get("after") is not None:  # noqa: E501
            query_params.append(("after", local_var_params["after"]))  # noqa: E501
        if local_var_params.get("limit") is not None:  # noqa: E501
            query_params.append(("limit", local_var_params["limit"]))  # noqa: E501
        if local_var_params.get("properties") is not None:  # noqa: E501
            query_params.append(("properties", local_var_params["properties"]))  # noqa: E501
            collection_formats["properties"] = "multi"  # noqa: E501
        if local_var_params.get("offset") is not None:  # noqa: E501
            query_params.append(("offset", local_var_params["offset"]))  # noqa: E501
        if local_var_params.get("archived") is not None:  # noqa: E501
            query_params.append(("archived", local_var_params["archived"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "UnifiedCollectionResponseWithTotalBaseHubDbTableRowV3",
        }

        return self.api_client.call_api(
            "/cms/v3/hubdb/tables/{tableIdOrName}/rows",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def purge_draft_table_row(self, table_id_or_name, row_id, **kwargs):  # noqa: E501
        """Permanently deletes a row  # noqa: E501

        Permanently deletes a row from a table's draft version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.purge_draft_table_row(table_id_or_name, row_id, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table (required)
        :type table_id_or_name: str
        :param row_id: The ID of the row (required)
        :type row_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.purge_draft_table_row_with_http_info(table_id_or_name, row_id, **kwargs)  # noqa: E501

    def purge_draft_table_row_with_http_info(self, table_id_or_name, row_id, **kwargs):  # noqa: E501
        """Permanently deletes a row  # noqa: E501

        Permanently deletes a row from a table's draft version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.purge_draft_table_row_with_http_info(table_id_or_name, row_id, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table (required)
        :type table_id_or_name: str
        :param row_id: The ID of the row (required)
        :type row_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["table_id_or_name", "row_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method purge_draft_table_row" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'table_id_or_name' is set
        if self.api_client.client_side_validation and local_var_params.get("table_id_or_name") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `table_id_or_name` when calling `purge_draft_table_row`")  # noqa: E501
        # verify the required parameter 'row_id' is set
        if self.api_client.client_side_validation and local_var_params.get("row_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `row_id` when calling `purge_draft_table_row`")  # noqa: E501

        if self.api_client.client_side_validation and "row_id" in local_var_params and not re.search(r"\d+", local_var_params["row_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `row_id` when calling `purge_draft_table_row`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "table_id_or_name" in local_var_params:
            path_params["tableIdOrName"] = local_var_params["table_id_or_name"]  # noqa: E501
        if "row_id" in local_var_params:
            path_params["rowId"] = local_var_params["row_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/cms/v3/hubdb/tables/{tableIdOrName}/rows/{rowId}/draft",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def read_draft_table_rows(self, table_id_or_name, **kwargs):  # noqa: E501
        """Get rows from draft table  # noqa: E501

        Returns rows in the draft version of the specified table. Row results can be filtered and sorted. Filtering and sorting options will be sent as query parameters to the API request. For example, by adding the query parameters `column1__gt=5&sort=-column1`, API returns the rows with values for column `column1` greater than 5 and in the descending order of `column1` values. Refer to the [overview section](https://developers.hubspot.com/docs/api/cms/hubdb#filtering-and-sorting-table-rows) for detailed filtering and sorting options.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.read_draft_table_rows(table_id_or_name, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table to query. (required)
        :type table_id_or_name: str
        :param sort: Specifies the column names to sort the results by.
        :type sort: list[str]
        :param after: The cursor token value to get the next set of results. You can get this from the `paging.next.after` JSON property of a paged response containing more results.
        :type after: str
        :param limit: The maximum number of results to return. Default is `1000`.
        :type limit: int
        :param properties: Specify the column names to get results containing only the required columns instead of all column details. If you want to include multiple columns in the result, use this query param as many times.
        :type properties: list[str]
        :param offset:
        :type offset: int
        :param archived:
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UnifiedCollectionResponseWithTotalBaseHubDbTableRowV3
        """
        kwargs["_return_http_data_only"] = True
        return self.read_draft_table_rows_with_http_info(table_id_or_name, **kwargs)  # noqa: E501

    def read_draft_table_rows_with_http_info(self, table_id_or_name, **kwargs):  # noqa: E501
        """Get rows from draft table  # noqa: E501

        Returns rows in the draft version of the specified table. Row results can be filtered and sorted. Filtering and sorting options will be sent as query parameters to the API request. For example, by adding the query parameters `column1__gt=5&sort=-column1`, API returns the rows with values for column `column1` greater than 5 and in the descending order of `column1` values. Refer to the [overview section](https://developers.hubspot.com/docs/api/cms/hubdb#filtering-and-sorting-table-rows) for detailed filtering and sorting options.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.read_draft_table_rows_with_http_info(table_id_or_name, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table to query. (required)
        :type table_id_or_name: str
        :param sort: Specifies the column names to sort the results by.
        :type sort: list[str]
        :param after: The cursor token value to get the next set of results. You can get this from the `paging.next.after` JSON property of a paged response containing more results.
        :type after: str
        :param limit: The maximum number of results to return. Default is `1000`.
        :type limit: int
        :param properties: Specify the column names to get results containing only the required columns instead of all column details. If you want to include multiple columns in the result, use this query param as many times.
        :type properties: list[str]
        :param offset:
        :type offset: int
        :param archived:
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(UnifiedCollectionResponseWithTotalBaseHubDbTableRowV3, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["table_id_or_name", "sort", "after", "limit", "properties", "offset", "archived"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method read_draft_table_rows" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'table_id_or_name' is set
        if self.api_client.client_side_validation and local_var_params.get("table_id_or_name") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `table_id_or_name` when calling `read_draft_table_rows`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "table_id_or_name" in local_var_params:
            path_params["tableIdOrName"] = local_var_params["table_id_or_name"]  # noqa: E501

        query_params = []
        if local_var_params.get("sort") is not None:  # noqa: E501
            query_params.append(("sort", local_var_params["sort"]))  # noqa: E501
            collection_formats["sort"] = "multi"  # noqa: E501
        if local_var_params.get("after") is not None:  # noqa: E501
            query_params.append(("after", local_var_params["after"]))  # noqa: E501
        if local_var_params.get("limit") is not None:  # noqa: E501
            query_params.append(("limit", local_var_params["limit"]))  # noqa: E501
        if local_var_params.get("properties") is not None:  # noqa: E501
            query_params.append(("properties", local_var_params["properties"]))  # noqa: E501
            collection_formats["properties"] = "multi"  # noqa: E501
        if local_var_params.get("offset") is not None:  # noqa: E501
            query_params.append(("offset", local_var_params["offset"]))  # noqa: E501
        if local_var_params.get("archived") is not None:  # noqa: E501
            query_params.append(("archived", local_var_params["archived"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "UnifiedCollectionResponseWithTotalBaseHubDbTableRowV3",
        }

        return self.api_client.call_api(
            "/cms/v3/hubdb/tables/{tableIdOrName}/rows/draft",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def replace_draft_table_row(self, table_id_or_name, row_id, hub_db_table_row_v3_request, **kwargs):  # noqa: E501
        """Replaces an existing row  # noqa: E501

        Replace a single row in the draft version of a table. All column values must be specified. If a column has a value in the target table and this request doesn't define that value, it will be deleted. See the \"Create a row\" endpoint for instructions on how to format the JSON row definitions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.replace_draft_table_row(table_id_or_name, row_id, hub_db_table_row_v3_request, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table (required)
        :type table_id_or_name: str
        :param row_id: The ID of the row (required)
        :type row_id: str
        :param hub_db_table_row_v3_request: (required)
        :type hub_db_table_row_v3_request: HubDbTableRowV3Request
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HubDbTableRowV3
        """
        kwargs["_return_http_data_only"] = True
        return self.replace_draft_table_row_with_http_info(table_id_or_name, row_id, hub_db_table_row_v3_request, **kwargs)  # noqa: E501

    def replace_draft_table_row_with_http_info(self, table_id_or_name, row_id, hub_db_table_row_v3_request, **kwargs):  # noqa: E501
        """Replaces an existing row  # noqa: E501

        Replace a single row in the draft version of a table. All column values must be specified. If a column has a value in the target table and this request doesn't define that value, it will be deleted. See the \"Create a row\" endpoint for instructions on how to format the JSON row definitions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.replace_draft_table_row_with_http_info(table_id_or_name, row_id, hub_db_table_row_v3_request, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table (required)
        :type table_id_or_name: str
        :param row_id: The ID of the row (required)
        :type row_id: str
        :param hub_db_table_row_v3_request: (required)
        :type hub_db_table_row_v3_request: HubDbTableRowV3Request
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(HubDbTableRowV3, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["table_id_or_name", "row_id", "hub_db_table_row_v3_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method replace_draft_table_row" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'table_id_or_name' is set
        if self.api_client.client_side_validation and local_var_params.get("table_id_or_name") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `table_id_or_name` when calling `replace_draft_table_row`")  # noqa: E501
        # verify the required parameter 'row_id' is set
        if self.api_client.client_side_validation and local_var_params.get("row_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `row_id` when calling `replace_draft_table_row`")  # noqa: E501
        # verify the required parameter 'hub_db_table_row_v3_request' is set
        if self.api_client.client_side_validation and local_var_params.get("hub_db_table_row_v3_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `hub_db_table_row_v3_request` when calling `replace_draft_table_row`")  # noqa: E501

        if self.api_client.client_side_validation and "row_id" in local_var_params and not re.search(r"\d+", local_var_params["row_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `row_id` when calling `replace_draft_table_row`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "table_id_or_name" in local_var_params:
            path_params["tableIdOrName"] = local_var_params["table_id_or_name"]  # noqa: E501
        if "row_id" in local_var_params:
            path_params["rowId"] = local_var_params["row_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "hub_db_table_row_v3_request" in local_var_params:
            body_params = local_var_params["hub_db_table_row_v3_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PUT", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "HubDbTableRowV3",
        }

        return self.api_client.call_api(
            "/cms/v3/hubdb/tables/{tableIdOrName}/rows/{rowId}/draft",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update_draft_table_row(self, table_id_or_name, row_id, hub_db_table_row_v3_request, **kwargs):  # noqa: E501
        """Updates an existing row  # noqa: E501

        Sparse updates a single row in the table's draft version. All the column values need not be specified. Only the columns or fields that needs to be modified can be specified. See the \"Create a row\" endpoint for instructions on how to format the JSON row definitions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_draft_table_row(table_id_or_name, row_id, hub_db_table_row_v3_request, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table (required)
        :type table_id_or_name: str
        :param row_id: The ID of the row (required)
        :type row_id: str
        :param hub_db_table_row_v3_request: (required)
        :type hub_db_table_row_v3_request: HubDbTableRowV3Request
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: HubDbTableRowV3
        """
        kwargs["_return_http_data_only"] = True
        return self.update_draft_table_row_with_http_info(table_id_or_name, row_id, hub_db_table_row_v3_request, **kwargs)  # noqa: E501

    def update_draft_table_row_with_http_info(self, table_id_or_name, row_id, hub_db_table_row_v3_request, **kwargs):  # noqa: E501
        """Updates an existing row  # noqa: E501

        Sparse updates a single row in the table's draft version. All the column values need not be specified. Only the columns or fields that needs to be modified can be specified. See the \"Create a row\" endpoint for instructions on how to format the JSON row definitions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_draft_table_row_with_http_info(table_id_or_name, row_id, hub_db_table_row_v3_request, async_req=True)
        >>> result = thread.get()

        :param table_id_or_name: The ID or name of the table (required)
        :type table_id_or_name: str
        :param row_id: The ID of the row (required)
        :type row_id: str
        :param hub_db_table_row_v3_request: (required)
        :type hub_db_table_row_v3_request: HubDbTableRowV3Request
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(HubDbTableRowV3, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["table_id_or_name", "row_id", "hub_db_table_row_v3_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update_draft_table_row" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'table_id_or_name' is set
        if self.api_client.client_side_validation and local_var_params.get("table_id_or_name") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `table_id_or_name` when calling `update_draft_table_row`")  # noqa: E501
        # verify the required parameter 'row_id' is set
        if self.api_client.client_side_validation and local_var_params.get("row_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `row_id` when calling `update_draft_table_row`")  # noqa: E501
        # verify the required parameter 'hub_db_table_row_v3_request' is set
        if self.api_client.client_side_validation and local_var_params.get("hub_db_table_row_v3_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `hub_db_table_row_v3_request` when calling `update_draft_table_row`")  # noqa: E501

        if self.api_client.client_side_validation and "row_id" in local_var_params and not re.search(r"\d+", local_var_params["row_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `row_id` when calling `update_draft_table_row`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "table_id_or_name" in local_var_params:
            path_params["tableIdOrName"] = local_var_params["table_id_or_name"]  # noqa: E501
        if "row_id" in local_var_params:
            path_params["rowId"] = local_var_params["row_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "hub_db_table_row_v3_request" in local_var_params:
            body_params = local_var_params["hub_db_table_row_v3_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PATCH", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "HubDbTableRowV3",
        }

        return self.api_client.call_api(
            "/cms/v3/hubdb/tables/{tableIdOrName}/rows/{rowId}/draft",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

# flake8: noqa

"""
    CMS Domains

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.cms.domains.api.domains_api import DomainsApi

# import ApiClient
from hubspot.cms.domains.api_client import ApiClient
from hubspot.cms.domains.configuration import Configuration
from hubspot.cms.domains.exceptions import OpenApiException
from hubspot.cms.domains.exceptions import ApiTypeError
from hubspot.cms.domains.exceptions import ApiValueError
from hubspot.cms.domains.exceptions import ApiKeyError
from hubspot.cms.domains.exceptions import ApiAttributeError
from hubspot.cms.domains.exceptions import ApiException

# import models into sdk package
from hubspot.cms.domains.models.collection_response_with_total_domain_forward_paging import CollectionResponseWithTotalDomainForwardPaging
from hubspot.cms.domains.models.domain import Domain
from hubspot.cms.domains.models.error import Error
from hubspot.cms.domains.models.error_detail import ErrorDetail
from hubspot.cms.domains.models.forward_paging import ForwardPaging
from hubspot.cms.domains.models.next_page import NextPage



# coding: utf-8

"""
    Communication Preferences Subscriptions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.communication_preferences.configuration import Configuration


class SubscriptionDefinition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "is_internal": "bool",
        "created_at": "datetime",
        "is_default": "bool",
        "communication_method": "str",
        "purpose": "str",
        "name": "str",
        "description": "str",
        "id": "str",
        "is_active": "bool",
        "business_unit_id": "int",
        "updated_at": "datetime",
    }

    attribute_map = {
        "is_internal": "isInternal",
        "created_at": "createdAt",
        "is_default": "isDefault",
        "communication_method": "communicationMethod",
        "purpose": "purpose",
        "name": "name",
        "description": "description",
        "id": "id",
        "is_active": "isActive",
        "business_unit_id": "businessUnitId",
        "updated_at": "updatedAt",
    }

    def __init__(
        self,
        is_internal=None,
        created_at=None,
        is_default=None,
        communication_method=None,
        purpose=None,
        name=None,
        description=None,
        id=None,
        is_active=None,
        business_unit_id=None,
        updated_at=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """SubscriptionDefinition - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._is_internal = None
        self._created_at = None
        self._is_default = None
        self._communication_method = None
        self._purpose = None
        self._name = None
        self._description = None
        self._id = None
        self._is_active = None
        self._business_unit_id = None
        self._updated_at = None
        self.discriminator = None

        self.is_internal = is_internal
        self.created_at = created_at
        self.is_default = is_default
        if communication_method is not None:
            self.communication_method = communication_method
        if purpose is not None:
            self.purpose = purpose
        self.name = name
        self.description = description
        self.id = id
        self.is_active = is_active
        if business_unit_id is not None:
            self.business_unit_id = business_unit_id
        self.updated_at = updated_at

    @property
    def is_internal(self):
        """Gets the is_internal of this SubscriptionDefinition.  # noqa: E501

        A default description that is used by some HubSpot tools and cannot be edited.  # noqa: E501

        :return: The is_internal of this SubscriptionDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._is_internal

    @is_internal.setter
    def is_internal(self, is_internal):
        """Sets the is_internal of this SubscriptionDefinition.

        A default description that is used by some HubSpot tools and cannot be edited.  # noqa: E501

        :param is_internal: The is_internal of this SubscriptionDefinition.  # noqa: E501
        :type is_internal: bool
        """
        if self.local_vars_configuration.client_side_validation and is_internal is None:  # noqa: E501
            raise ValueError("Invalid value for `is_internal`, must not be `None`")  # noqa: E501

        self._is_internal = is_internal

    @property
    def created_at(self):
        """Gets the created_at of this SubscriptionDefinition.  # noqa: E501

        Time at which the definition was created.  # noqa: E501

        :return: The created_at of this SubscriptionDefinition.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SubscriptionDefinition.

        Time at which the definition was created.  # noqa: E501

        :param created_at: The created_at of this SubscriptionDefinition.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def is_default(self):
        """Gets the is_default of this SubscriptionDefinition.  # noqa: E501

        A subscription definition created by HubSpot.  # noqa: E501

        :return: The is_default of this SubscriptionDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this SubscriptionDefinition.

        A subscription definition created by HubSpot.  # noqa: E501

        :param is_default: The is_default of this SubscriptionDefinition.  # noqa: E501
        :type is_default: bool
        """
        if self.local_vars_configuration.client_side_validation and is_default is None:  # noqa: E501
            raise ValueError("Invalid value for `is_default`, must not be `None`")  # noqa: E501

        self._is_default = is_default

    @property
    def communication_method(self):
        """Gets the communication_method of this SubscriptionDefinition.  # noqa: E501

        The method or technology used to contact.  # noqa: E501

        :return: The communication_method of this SubscriptionDefinition.  # noqa: E501
        :rtype: str
        """
        return self._communication_method

    @communication_method.setter
    def communication_method(self, communication_method):
        """Sets the communication_method of this SubscriptionDefinition.

        The method or technology used to contact.  # noqa: E501

        :param communication_method: The communication_method of this SubscriptionDefinition.  # noqa: E501
        :type communication_method: str
        """

        self._communication_method = communication_method

    @property
    def purpose(self):
        """Gets the purpose of this SubscriptionDefinition.  # noqa: E501

        The purpose of this subscription or the department in your organization that uses it.  # noqa: E501

        :return: The purpose of this SubscriptionDefinition.  # noqa: E501
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """Sets the purpose of this SubscriptionDefinition.

        The purpose of this subscription or the department in your organization that uses it.  # noqa: E501

        :param purpose: The purpose of this SubscriptionDefinition.  # noqa: E501
        :type purpose: str
        """

        self._purpose = purpose

    @property
    def name(self):
        """Gets the name of this SubscriptionDefinition.  # noqa: E501

        The name of the subscription.  # noqa: E501

        :return: The name of this SubscriptionDefinition.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SubscriptionDefinition.

        The name of the subscription.  # noqa: E501

        :param name: The name of this SubscriptionDefinition.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this SubscriptionDefinition.  # noqa: E501

        A description of the subscription.  # noqa: E501

        :return: The description of this SubscriptionDefinition.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SubscriptionDefinition.

        A description of the subscription.  # noqa: E501

        :param description: The description of this SubscriptionDefinition.  # noqa: E501
        :type description: str
        """
        if self.local_vars_configuration.client_side_validation and description is None:  # noqa: E501
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def id(self):
        """Gets the id of this SubscriptionDefinition.  # noqa: E501

        The ID of the definition.  # noqa: E501

        :return: The id of this SubscriptionDefinition.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionDefinition.

        The ID of the definition.  # noqa: E501

        :param id: The id of this SubscriptionDefinition.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def is_active(self):
        """Gets the is_active of this SubscriptionDefinition.  # noqa: E501

        Whether the definition is active or archived.  # noqa: E501

        :return: The is_active of this SubscriptionDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """Sets the is_active of this SubscriptionDefinition.

        Whether the definition is active or archived.  # noqa: E501

        :param is_active: The is_active of this SubscriptionDefinition.  # noqa: E501
        :type is_active: bool
        """
        if self.local_vars_configuration.client_side_validation and is_active is None:  # noqa: E501
            raise ValueError("Invalid value for `is_active`, must not be `None`")  # noqa: E501

        self._is_active = is_active

    @property
    def business_unit_id(self):
        """Gets the business_unit_id of this SubscriptionDefinition.  # noqa: E501


        :return: The business_unit_id of this SubscriptionDefinition.  # noqa: E501
        :rtype: int
        """
        return self._business_unit_id

    @business_unit_id.setter
    def business_unit_id(self, business_unit_id):
        """Sets the business_unit_id of this SubscriptionDefinition.


        :param business_unit_id: The business_unit_id of this SubscriptionDefinition.  # noqa: E501
        :type business_unit_id: int
        """

        self._business_unit_id = business_unit_id

    @property
    def updated_at(self):
        """Gets the updated_at of this SubscriptionDefinition.  # noqa: E501

        Time at which the definition was last updated.  # noqa: E501

        :return: The updated_at of this SubscriptionDefinition.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this SubscriptionDefinition.

        Time at which the definition was last updated.  # noqa: E501

        :param updated_at: The updated_at of this SubscriptionDefinition.  # noqa: E501
        :type updated_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubscriptionDefinition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SubscriptionDefinition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CMS Url Redirects

    URL redirect operations  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.url_redirects.configuration import Configuration


class UrlMappingCreateRequestBody(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "is_trailing_slash_optional": "bool",
        "is_match_query_string": "bool",
        "redirect_style": "int",
        "route_prefix": "str",
        "is_match_full_url": "bool",
        "is_protocol_agnostic": "bool",
        "destination": "str",
        "is_only_after_not_found": "bool",
        "is_pattern": "bool",
        "precedence": "int",
    }

    attribute_map = {
        "is_trailing_slash_optional": "isTrailingSlashOptional",
        "is_match_query_string": "isMatchQueryString",
        "redirect_style": "redirectStyle",
        "route_prefix": "routePrefix",
        "is_match_full_url": "isMatchFullUrl",
        "is_protocol_agnostic": "isProtocolAgnostic",
        "destination": "destination",
        "is_only_after_not_found": "isOnlyAfterNotFound",
        "is_pattern": "isPattern",
        "precedence": "precedence",
    }

    def __init__(
        self,
        is_trailing_slash_optional=None,
        is_match_query_string=None,
        redirect_style=None,
        route_prefix=None,
        is_match_full_url=None,
        is_protocol_agnostic=None,
        destination=None,
        is_only_after_not_found=None,
        is_pattern=None,
        precedence=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """UrlMappingCreateRequestBody - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._is_trailing_slash_optional = None
        self._is_match_query_string = None
        self._redirect_style = None
        self._route_prefix = None
        self._is_match_full_url = None
        self._is_protocol_agnostic = None
        self._destination = None
        self._is_only_after_not_found = None
        self._is_pattern = None
        self._precedence = None
        self.discriminator = None

        if is_trailing_slash_optional is not None:
            self.is_trailing_slash_optional = is_trailing_slash_optional
        if is_match_query_string is not None:
            self.is_match_query_string = is_match_query_string
        self.redirect_style = redirect_style
        self.route_prefix = route_prefix
        if is_match_full_url is not None:
            self.is_match_full_url = is_match_full_url
        if is_protocol_agnostic is not None:
            self.is_protocol_agnostic = is_protocol_agnostic
        self.destination = destination
        if is_only_after_not_found is not None:
            self.is_only_after_not_found = is_only_after_not_found
        if is_pattern is not None:
            self.is_pattern = is_pattern
        if precedence is not None:
            self.precedence = precedence

    @property
    def is_trailing_slash_optional(self):
        """Gets the is_trailing_slash_optional of this UrlMappingCreateRequestBody.  # noqa: E501


        :return: The is_trailing_slash_optional of this UrlMappingCreateRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_trailing_slash_optional

    @is_trailing_slash_optional.setter
    def is_trailing_slash_optional(self, is_trailing_slash_optional):
        """Sets the is_trailing_slash_optional of this UrlMappingCreateRequestBody.


        :param is_trailing_slash_optional: The is_trailing_slash_optional of this UrlMappingCreateRequestBody.  # noqa: E501
        :type is_trailing_slash_optional: bool
        """

        self._is_trailing_slash_optional = is_trailing_slash_optional

    @property
    def is_match_query_string(self):
        """Gets the is_match_query_string of this UrlMappingCreateRequestBody.  # noqa: E501


        :return: The is_match_query_string of this UrlMappingCreateRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_match_query_string

    @is_match_query_string.setter
    def is_match_query_string(self, is_match_query_string):
        """Sets the is_match_query_string of this UrlMappingCreateRequestBody.


        :param is_match_query_string: The is_match_query_string of this UrlMappingCreateRequestBody.  # noqa: E501
        :type is_match_query_string: bool
        """

        self._is_match_query_string = is_match_query_string

    @property
    def redirect_style(self):
        """Gets the redirect_style of this UrlMappingCreateRequestBody.  # noqa: E501


        :return: The redirect_style of this UrlMappingCreateRequestBody.  # noqa: E501
        :rtype: int
        """
        return self._redirect_style

    @redirect_style.setter
    def redirect_style(self, redirect_style):
        """Sets the redirect_style of this UrlMappingCreateRequestBody.


        :param redirect_style: The redirect_style of this UrlMappingCreateRequestBody.  # noqa: E501
        :type redirect_style: int
        """
        if self.local_vars_configuration.client_side_validation and redirect_style is None:  # noqa: E501
            raise ValueError("Invalid value for `redirect_style`, must not be `None`")  # noqa: E501

        self._redirect_style = redirect_style

    @property
    def route_prefix(self):
        """Gets the route_prefix of this UrlMappingCreateRequestBody.  # noqa: E501


        :return: The route_prefix of this UrlMappingCreateRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._route_prefix

    @route_prefix.setter
    def route_prefix(self, route_prefix):
        """Sets the route_prefix of this UrlMappingCreateRequestBody.


        :param route_prefix: The route_prefix of this UrlMappingCreateRequestBody.  # noqa: E501
        :type route_prefix: str
        """
        if self.local_vars_configuration.client_side_validation and route_prefix is None:  # noqa: E501
            raise ValueError("Invalid value for `route_prefix`, must not be `None`")  # noqa: E501

        self._route_prefix = route_prefix

    @property
    def is_match_full_url(self):
        """Gets the is_match_full_url of this UrlMappingCreateRequestBody.  # noqa: E501


        :return: The is_match_full_url of this UrlMappingCreateRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_match_full_url

    @is_match_full_url.setter
    def is_match_full_url(self, is_match_full_url):
        """Sets the is_match_full_url of this UrlMappingCreateRequestBody.


        :param is_match_full_url: The is_match_full_url of this UrlMappingCreateRequestBody.  # noqa: E501
        :type is_match_full_url: bool
        """

        self._is_match_full_url = is_match_full_url

    @property
    def is_protocol_agnostic(self):
        """Gets the is_protocol_agnostic of this UrlMappingCreateRequestBody.  # noqa: E501


        :return: The is_protocol_agnostic of this UrlMappingCreateRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_protocol_agnostic

    @is_protocol_agnostic.setter
    def is_protocol_agnostic(self, is_protocol_agnostic):
        """Sets the is_protocol_agnostic of this UrlMappingCreateRequestBody.


        :param is_protocol_agnostic: The is_protocol_agnostic of this UrlMappingCreateRequestBody.  # noqa: E501
        :type is_protocol_agnostic: bool
        """

        self._is_protocol_agnostic = is_protocol_agnostic

    @property
    def destination(self):
        """Gets the destination of this UrlMappingCreateRequestBody.  # noqa: E501


        :return: The destination of this UrlMappingCreateRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this UrlMappingCreateRequestBody.


        :param destination: The destination of this UrlMappingCreateRequestBody.  # noqa: E501
        :type destination: str
        """
        if self.local_vars_configuration.client_side_validation and destination is None:  # noqa: E501
            raise ValueError("Invalid value for `destination`, must not be `None`")  # noqa: E501

        self._destination = destination

    @property
    def is_only_after_not_found(self):
        """Gets the is_only_after_not_found of this UrlMappingCreateRequestBody.  # noqa: E501


        :return: The is_only_after_not_found of this UrlMappingCreateRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_only_after_not_found

    @is_only_after_not_found.setter
    def is_only_after_not_found(self, is_only_after_not_found):
        """Sets the is_only_after_not_found of this UrlMappingCreateRequestBody.


        :param is_only_after_not_found: The is_only_after_not_found of this UrlMappingCreateRequestBody.  # noqa: E501
        :type is_only_after_not_found: bool
        """

        self._is_only_after_not_found = is_only_after_not_found

    @property
    def is_pattern(self):
        """Gets the is_pattern of this UrlMappingCreateRequestBody.  # noqa: E501


        :return: The is_pattern of this UrlMappingCreateRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_pattern

    @is_pattern.setter
    def is_pattern(self, is_pattern):
        """Sets the is_pattern of this UrlMappingCreateRequestBody.


        :param is_pattern: The is_pattern of this UrlMappingCreateRequestBody.  # noqa: E501
        :type is_pattern: bool
        """

        self._is_pattern = is_pattern

    @property
    def precedence(self):
        """Gets the precedence of this UrlMappingCreateRequestBody.  # noqa: E501


        :return: The precedence of this UrlMappingCreateRequestBody.  # noqa: E501
        :rtype: int
        """
        return self._precedence

    @precedence.setter
    def precedence(self, precedence):
        """Sets the precedence of this UrlMappingCreateRequestBody.


        :param precedence: The precedence of this UrlMappingCreateRequestBody.  # noqa: E501
        :type precedence: int
        """

        self._precedence = precedence

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UrlMappingCreateRequestBody):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UrlMappingCreateRequestBody):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    CMS Source Code

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.cms.source_code.models.action_response import ActionResponse
from hubspot.cms.source_code.models.asset_file_metadata import AssetFileMetadata
from hubspot.cms.source_code.models.error import Error
from hubspot.cms.source_code.models.error_detail import ErrorDetail
from hubspot.cms.source_code.models.file_extract_request import FileExtractRequest
from hubspot.cms.source_code.models.task_locator import TaskLocator



# coding: utf-8

"""
    CRM Associations

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.crm.associations.v4.api_client import ApiClient
from hubspot.crm.associations.v4.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class BasicApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive(self, object_type, object_id, to_object_type, to_object_id, **kwargs):  # noqa: E501
        """Delete  # noqa: E501

        deletes all associations between two records.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive(object_type, object_id, to_object_type, to_object_id, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param object_id: (required)
        :type object_id: str
        :param to_object_type: (required)
        :type to_object_type: str
        :param to_object_id: (required)
        :type to_object_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_with_http_info(object_type, object_id, to_object_type, to_object_id, **kwargs)  # noqa: E501

    def archive_with_http_info(self, object_type, object_id, to_object_type, to_object_id, **kwargs):  # noqa: E501
        """Delete  # noqa: E501

        deletes all associations between two records.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_with_http_info(object_type, object_id, to_object_type, to_object_id, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param object_id: (required)
        :type object_id: str
        :param to_object_type: (required)
        :type to_object_type: str
        :param to_object_id: (required)
        :type to_object_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["object_type", "object_id", "to_object_type", "to_object_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type` when calling `archive`")  # noqa: E501
        # verify the required parameter 'object_id' is set
        if self.api_client.client_side_validation and local_var_params.get("object_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_id` when calling `archive`")  # noqa: E501
        # verify the required parameter 'to_object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("to_object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `to_object_type` when calling `archive`")  # noqa: E501
        # verify the required parameter 'to_object_id' is set
        if self.api_client.client_side_validation and local_var_params.get("to_object_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `to_object_id` when calling `archive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type" in local_var_params:
            path_params["objectType"] = local_var_params["object_type"]  # noqa: E501
        if "object_id" in local_var_params:
            path_params["objectId"] = local_var_params["object_id"]  # noqa: E501
        if "to_object_type" in local_var_params:
            path_params["toObjectType"] = local_var_params["to_object_type"]  # noqa: E501
        if "to_object_id" in local_var_params:
            path_params["toObjectId"] = local_var_params["to_object_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/crm/v4/objects/{objectType}/{objectId}/associations/{toObjectType}/{toObjectId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create(self, object_type, object_id, to_object_type, to_object_id, association_spec, **kwargs):  # noqa: E501
        """Create  # noqa: E501

        Set association labels between two records.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create(object_type, object_id, to_object_type, to_object_id, association_spec, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param object_id: (required)
        :type object_id: str
        :param to_object_type: (required)
        :type to_object_type: str
        :param to_object_id: (required)
        :type to_object_id: str
        :param association_spec: (required)
        :type association_spec: list[AssociationSpec]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: LabelsBetweenObjectPair
        """
        kwargs["_return_http_data_only"] = True
        return self.create_with_http_info(object_type, object_id, to_object_type, to_object_id, association_spec, **kwargs)  # noqa: E501

    def create_with_http_info(self, object_type, object_id, to_object_type, to_object_id, association_spec, **kwargs):  # noqa: E501
        """Create  # noqa: E501

        Set association labels between two records.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_with_http_info(object_type, object_id, to_object_type, to_object_id, association_spec, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param object_id: (required)
        :type object_id: str
        :param to_object_type: (required)
        :type to_object_type: str
        :param to_object_id: (required)
        :type to_object_id: str
        :param association_spec: (required)
        :type association_spec: list[AssociationSpec]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(LabelsBetweenObjectPair, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_type", "object_id", "to_object_type", "to_object_id", "association_spec"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type` when calling `create`")  # noqa: E501
        # verify the required parameter 'object_id' is set
        if self.api_client.client_side_validation and local_var_params.get("object_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_id` when calling `create`")  # noqa: E501
        # verify the required parameter 'to_object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("to_object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `to_object_type` when calling `create`")  # noqa: E501
        # verify the required parameter 'to_object_id' is set
        if self.api_client.client_side_validation and local_var_params.get("to_object_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `to_object_id` when calling `create`")  # noqa: E501
        # verify the required parameter 'association_spec' is set
        if self.api_client.client_side_validation and local_var_params.get("association_spec") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `association_spec` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type" in local_var_params:
            path_params["objectType"] = local_var_params["object_type"]  # noqa: E501
        if "object_id" in local_var_params:
            path_params["objectId"] = local_var_params["object_id"]  # noqa: E501
        if "to_object_type" in local_var_params:
            path_params["toObjectType"] = local_var_params["to_object_type"]  # noqa: E501
        if "to_object_id" in local_var_params:
            path_params["toObjectId"] = local_var_params["to_object_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "association_spec" in local_var_params:
            body_params = local_var_params["association_spec"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PUT", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            201: "LabelsBetweenObjectPair",
        }

        return self.api_client.call_api(
            "/crm/v4/objects/{objectType}/{objectId}/associations/{toObjectType}/{toObjectId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create_default(self, from_object_type, from_object_id, to_object_type, to_object_id, **kwargs):  # noqa: E501
        """Create Default  # noqa: E501

        Create the default (most generic) association type between two object types  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_default(from_object_type, from_object_id, to_object_type, to_object_id, async_req=True)
        >>> result = thread.get()

        :param from_object_type: (required)
        :type from_object_type: str
        :param from_object_id: (required)
        :type from_object_id: str
        :param to_object_type: (required)
        :type to_object_type: str
        :param to_object_id: (required)
        :type to_object_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BatchResponsePublicDefaultAssociation
        """
        kwargs["_return_http_data_only"] = True
        return self.create_default_with_http_info(from_object_type, from_object_id, to_object_type, to_object_id, **kwargs)  # noqa: E501

    def create_default_with_http_info(self, from_object_type, from_object_id, to_object_type, to_object_id, **kwargs):  # noqa: E501
        """Create Default  # noqa: E501

        Create the default (most generic) association type between two object types  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_default_with_http_info(from_object_type, from_object_id, to_object_type, to_object_id, async_req=True)
        >>> result = thread.get()

        :param from_object_type: (required)
        :type from_object_type: str
        :param from_object_id: (required)
        :type from_object_id: str
        :param to_object_type: (required)
        :type to_object_type: str
        :param to_object_id: (required)
        :type to_object_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BatchResponsePublicDefaultAssociation, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["from_object_type", "from_object_id", "to_object_type", "to_object_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create_default" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'from_object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("from_object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `from_object_type` when calling `create_default`")  # noqa: E501
        # verify the required parameter 'from_object_id' is set
        if self.api_client.client_side_validation and local_var_params.get("from_object_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `from_object_id` when calling `create_default`")  # noqa: E501
        # verify the required parameter 'to_object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("to_object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `to_object_type` when calling `create_default`")  # noqa: E501
        # verify the required parameter 'to_object_id' is set
        if self.api_client.client_side_validation and local_var_params.get("to_object_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `to_object_id` when calling `create_default`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "from_object_type" in local_var_params:
            path_params["fromObjectType"] = local_var_params["from_object_type"]  # noqa: E501
        if "from_object_id" in local_var_params:
            path_params["fromObjectId"] = local_var_params["from_object_id"]  # noqa: E501
        if "to_object_type" in local_var_params:
            path_params["toObjectType"] = local_var_params["to_object_type"]  # noqa: E501
        if "to_object_id" in local_var_params:
            path_params["toObjectId"] = local_var_params["to_object_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "BatchResponsePublicDefaultAssociation",
        }

        return self.api_client.call_api(
            "/crm/v4/objects/{fromObjectType}/{fromObjectId}/associations/default/{toObjectType}/{toObjectId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_page(self, object_type, object_id, to_object_type, **kwargs):  # noqa: E501
        """List  # noqa: E501

        List all associations of an object by object type. Limit 500 per call.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_page(object_type, object_id, to_object_type, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param object_id: (required)
        :type object_id: str
        :param to_object_type: (required)
        :type to_object_type: str
        :param after: The paging cursor token of the last successfully read resource will be returned as the `paging.next.after` JSON property of a paged response containing more results.
        :type after: str
        :param limit: The maximum number of results to display per page.
        :type limit: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CollectionResponseMultiAssociatedObjectWithLabelForwardPaging
        """
        kwargs["_return_http_data_only"] = True
        return self.get_page_with_http_info(object_type, object_id, to_object_type, **kwargs)  # noqa: E501

    def get_page_with_http_info(self, object_type, object_id, to_object_type, **kwargs):  # noqa: E501
        """List  # noqa: E501

        List all associations of an object by object type. Limit 500 per call.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_page_with_http_info(object_type, object_id, to_object_type, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param object_id: (required)
        :type object_id: str
        :param to_object_type: (required)
        :type to_object_type: str
        :param after: The paging cursor token of the last successfully read resource will be returned as the `paging.next.after` JSON property of a paged response containing more results.
        :type after: str
        :param limit: The maximum number of results to display per page.
        :type limit: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CollectionResponseMultiAssociatedObjectWithLabelForwardPaging, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_type", "object_id", "to_object_type", "after", "limit"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_page" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type` when calling `get_page`")  # noqa: E501
        # verify the required parameter 'object_id' is set
        if self.api_client.client_side_validation and local_var_params.get("object_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_id` when calling `get_page`")  # noqa: E501
        # verify the required parameter 'to_object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("to_object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `to_object_type` when calling `get_page`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type" in local_var_params:
            path_params["objectType"] = local_var_params["object_type"]  # noqa: E501
        if "object_id" in local_var_params:
            path_params["objectId"] = local_var_params["object_id"]  # noqa: E501
        if "to_object_type" in local_var_params:
            path_params["toObjectType"] = local_var_params["to_object_type"]  # noqa: E501

        query_params = []
        if local_var_params.get("after") is not None:  # noqa: E501
            query_params.append(("after", local_var_params["after"]))  # noqa: E501
        if local_var_params.get("limit") is not None:  # noqa: E501
            query_params.append(("limit", local_var_params["limit"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "CollectionResponseMultiAssociatedObjectWithLabelForwardPaging",
        }

        return self.api_client.call_api(
            "/crm/v4/objects/{objectType}/{objectId}/associations/{toObjectType}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

# flake8: noqa

"""
    Business Units

    Retrieve Business Unit information.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.settings.business_units.api.business_unit_api import BusinessUnitApi

# import ApiClient
from hubspot.settings.business_units.api_client import ApiClient
from hubspot.settings.business_units.configuration import Configuration
from hubspot.settings.business_units.exceptions import OpenApiException
from hubspot.settings.business_units.exceptions import ApiTypeError
from hubspot.settings.business_units.exceptions import ApiValueError
from hubspot.settings.business_units.exceptions import ApiKeyError
from hubspot.settings.business_units.exceptions import ApiAttributeError
from hubspot.settings.business_units.exceptions import ApiException

# import models into sdk package
from hubspot.settings.business_units.models.collection_response_public_business_unit_no_paging import CollectionResponsePublicBusinessUnitNoPaging
from hubspot.settings.business_units.models.error import Error
from hubspot.settings.business_units.models.error_detail import ErrorDetail
from hubspot.settings.business_units.models.public_business_unit import PublicBusinessUnit
from hubspot.settings.business_units.models.public_business_unit_logo_metadata import PublicBusinessUnitLogoMetadata



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicEmailSubscriptionFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"subscription_type": "str", "subscription_ids": "list[str]", "filter_type": "str", "accepted_statuses": "list[str]"}

    attribute_map = {"subscription_type": "subscriptionType", "subscription_ids": "subscriptionIds", "filter_type": "filterType", "accepted_statuses": "acceptedStatuses"}

    def __init__(self, subscription_type=None, subscription_ids=None, filter_type="EMAIL_SUBSCRIPTION", accepted_statuses=None, local_vars_configuration=None):  # noqa: E501
        """PublicEmailSubscriptionFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._subscription_type = None
        self._subscription_ids = None
        self._filter_type = None
        self._accepted_statuses = None
        self.discriminator = None

        if subscription_type is not None:
            self.subscription_type = subscription_type
        self.subscription_ids = subscription_ids
        self.filter_type = filter_type
        self.accepted_statuses = accepted_statuses

    @property
    def subscription_type(self):
        """Gets the subscription_type of this PublicEmailSubscriptionFilter.  # noqa: E501


        :return: The subscription_type of this PublicEmailSubscriptionFilter.  # noqa: E501
        :rtype: str
        """
        return self._subscription_type

    @subscription_type.setter
    def subscription_type(self, subscription_type):
        """Sets the subscription_type of this PublicEmailSubscriptionFilter.


        :param subscription_type: The subscription_type of this PublicEmailSubscriptionFilter.  # noqa: E501
        :type subscription_type: str
        """

        self._subscription_type = subscription_type

    @property
    def subscription_ids(self):
        """Gets the subscription_ids of this PublicEmailSubscriptionFilter.  # noqa: E501


        :return: The subscription_ids of this PublicEmailSubscriptionFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._subscription_ids

    @subscription_ids.setter
    def subscription_ids(self, subscription_ids):
        """Sets the subscription_ids of this PublicEmailSubscriptionFilter.


        :param subscription_ids: The subscription_ids of this PublicEmailSubscriptionFilter.  # noqa: E501
        :type subscription_ids: list[str]
        """
        if self.local_vars_configuration.client_side_validation and subscription_ids is None:  # noqa: E501
            raise ValueError("Invalid value for `subscription_ids`, must not be `None`")  # noqa: E501

        self._subscription_ids = subscription_ids

    @property
    def filter_type(self):
        """Gets the filter_type of this PublicEmailSubscriptionFilter.  # noqa: E501


        :return: The filter_type of this PublicEmailSubscriptionFilter.  # noqa: E501
        :rtype: str
        """
        return self._filter_type

    @filter_type.setter
    def filter_type(self, filter_type):
        """Sets the filter_type of this PublicEmailSubscriptionFilter.


        :param filter_type: The filter_type of this PublicEmailSubscriptionFilter.  # noqa: E501
        :type filter_type: str
        """
        if self.local_vars_configuration.client_side_validation and filter_type is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_type`, must not be `None`")  # noqa: E501
        allowed_values = ["EMAIL_SUBSCRIPTION"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and filter_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `filter_type` ({0}), must be one of {1}".format(filter_type, allowed_values))  # noqa: E501

        self._filter_type = filter_type

    @property
    def accepted_statuses(self):
        """Gets the accepted_statuses of this PublicEmailSubscriptionFilter.  # noqa: E501


        :return: The accepted_statuses of this PublicEmailSubscriptionFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._accepted_statuses

    @accepted_statuses.setter
    def accepted_statuses(self, accepted_statuses):
        """Sets the accepted_statuses of this PublicEmailSubscriptionFilter.


        :param accepted_statuses: The accepted_statuses of this PublicEmailSubscriptionFilter.  # noqa: E501
        :type accepted_statuses: list[str]
        """
        if self.local_vars_configuration.client_side_validation and accepted_statuses is None:  # noqa: E501
            raise ValueError("Invalid value for `accepted_statuses`, must not be `None`")  # noqa: E501

        self._accepted_statuses = accepted_statuses

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicEmailSubscriptionFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicEmailSubscriptionFilter):
            return True

        return self.to_dict() != other.to_dict()
